<?php
/***************************************************************************
 * 
 * Copyright (c) 2017 Baidu.com, Inc. All Rights Reserved
 * 
 **************************************************************************/
 
/**
 * @file http_lib.php
 * @brief http get / post 请求
 *  
 **/

if(!extension_loaded('curl')){
    if(!dl('curl.so')){
        exit(-1);
    }
}

/**
 * @brief http get method
 * @param $url, string
 * @return array, error_no为0表示请求正常，data为请求返回结果。非0表示get请求异常，msg表示异常原因。
 */
function http_get($url){
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/46.0.2490.86 Safari/537.36');
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_TIMEOUT, 60);
    $data = curl_exec($ch);
    
    $result = [];
    $ret = curl_errno($ch);
    if($ret){
        $result['error_no'] = $ret;
        $result['msg'] = curl_error($ch);
    }else{
        $info = curl_getinfo($ch);
        $result['error_no'] = $ret;
        $result['http_code'] = $info['http_code'];
        $result['msg'] = 'success';
        $result['data'] = $data;
    } 
    return $result;
}

/**
 * @brief http post method
 * @param $url, string
 * @param $data, string | array
 * @param $opt, array，http header选项，如Content-Type=>application/json等
 * @return array, error_no为0表示请求正常，data为请求返回结果。非0表示get请求异常，msg表示异常原因。
 */
function http_post($url, $data, $opt=[]){
    $header = [];
    if(is_array($data)){
        $data = http_build_query($data);
    }
    if(isset($opt['content-type'])){
        $header[] = 'content-type: ' . $opt['content-type'];
    }else{
        $header[] = 'content-type: application/x-www-form-urlencoded';
    };
    $header[] = 'content-length: ' . strlen($data);

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/46.0.2490.86 Safari/537.36');
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_TIMEOUT, 30);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $header);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
    $data = curl_exec($ch);

    $result = [];
    $ret = curl_errno($ch);
    if($ret){
        $result['error_no'] = $ret;
        $result['msg'] = curl_error($ch);
    }else{
        $info = curl_getinfo($ch);
        $result['error_no'] = $ret;
        $result['http_code'] = $info['http_code'];
        $result['msg'] = 'success';
        $result['data'] = $data;
    } 
    return $result;
}


/* vim: set expandtab ts=4 sw=4 sts=4 tw=100: */
?>
